@@ -1,10 +1,5 @@
-=head NAME
-
-URI::Title::Image - get titles of images
-
-=cut
-
 package URI::Title::Image;
+$URI::Title::Image::VERSION = '1.901';
 use warnings;
 use strict;
 
@@ -15,6 +10,7 @@ sub types {(
   'image/jpg',
   'image/jpeg',
   'image/png',
+  'image/x-png',
 )}
 
 sub title {
@@ -22,8 +18,19 @@ sub title {
 
   my ($x, $y) = imgsize(\$data);
   $type =~ s!^[^/]*/!!;
+  $type =~ s!^x-!!;
   return $type unless $x && $y;
   return "$type ($x x $y)";
 }
 
 1;
+
+__END__
+
+=for Pod::Coverage::TrustPod types title
+
+=head1 NAME
+
+URI::Title::Image - get titles of images
+
+=cut
